@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_MYSQL_MNT_WORKSPACE_PERCONA_XTRADB_CLUSTER_5_7_SOURCE_TARBALL_PERCONA_XTRADB_CLUSTER_SQL_SQL_YACC_H_INCLUDED
-# define YY_MYSQL_MNT_WORKSPACE_PERCONA_XTRADB_CLUSTER_5_7_SOURCE_TARBALL_PERCONA_XTRADB_CLUSTER_SQL_SQL_YACC_H_INCLUDED
+#ifndef YY_MYSQL_MNT_JENKINS_WORKSPACE_PXC57_AUTOBUILD_RELEASE_TEST_PERCONA_XTRADB_CLUSTER_SQL_SQL_YACC_H_INCLUDED
+# define YY_MYSQL_MNT_JENKINS_WORKSPACE_PXC57_AUTOBUILD_RELEASE_TEST_PERCONA_XTRADB_CLUSTER_SQL_SQL_YACC_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -1409,4 +1409,4 @@ struct YYLTYPE
 
 int MYSQLparse (class THD *YYTHD);
 
-#endif /* !YY_MYSQL_MNT_WORKSPACE_PERCONA_XTRADB_CLUSTER_5_7_SOURCE_TARBALL_PERCONA_XTRADB_CLUSTER_SQL_SQL_YACC_H_INCLUDED  */
+#endif /* !YY_MYSQL_MNT_JENKINS_WORKSPACE_PXC57_AUTOBUILD_RELEASE_TEST_PERCONA_XTRADB_CLUSTER_SQL_SQL_YACC_H_INCLUDED  */
