@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 1996, 2022, Oracle and/or its affiliates.
+Copyright (c) 1996, 2023, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
@@ -2102,9 +2102,26 @@ row_upd_eval_new_vals(
 	}
 }
 
+/** Copies the data pointed to by the new values for virtual fields to update
+@param[in,out]	update		an update vector */
+static
+void
+row_upd_dup_v_new_vals(
+	const upd_t*	update)
+{
+	ut_ad(update != NULL);
+
+	for (ulint j = 0; j < upd_get_n_fields(update); j++) {
+		upd_field_t *upd_field = upd_get_nth_field(update, j);
+		if (upd_field->new_val.type.prtype & DATA_VIRTUAL) {
+			dfield_dup(&upd_field->new_val, update->heap);
+		}
+	}
+}
+
 /** Stores to the heap the virtual columns that need for any indexes
 @param[in,out]	node		row update node
-@param[in]	update		an update vector if it is update
+@param[in,out]	update		an update vector if it is update
 @param[in]	thd		mysql thread handle
 @param[in,out]	prebuilt	NULL, or a prebuilt object: used to extract
 				mysql table object when user thread invokes
@@ -2121,6 +2138,8 @@ row_upd_store_v_row(
 	dict_index_t*	index = dict_table_get_first_index(node->table);
 	TABLE*		mysql_table =
 		prebuilt ? prebuilt->m_mysql_table : NULL;
+	bool		new_val_v_cols_dup = false;
+	const ulint	n_upd = update ? upd_get_n_fields(update) : 0;
 
 	for (ulint col_no = 0; col_no < dict_table_get_n_v_cols(node->table);
 	     col_no++) {
@@ -2131,8 +2150,6 @@ row_upd_store_v_row(
 		if (col->m_col.ord_part) {
 			dfield_t*	dfield
 				= dtuple_get_nth_v_field(node->row, col_no);
-			ulint		n_upd
-				= update ? upd_get_n_fields(update) : 0;
 			ulint		i = 0;
 
 			/* Check if the value is already in update vector */
@@ -2169,6 +2186,11 @@ row_upd_store_v_row(
 						dfield_copy_data(dfield, vfield);
 						dfield_dup(dfield, node->heap);
 						if (dfield_is_null(dfield)) {
+						  if (!new_val_v_cols_dup) {
+						    row_upd_dup_v_new_vals(
+						      update);
+						    new_val_v_cols_dup = true;
+						  }
 						  innobase_get_computed_value(
 							node->row, col, index,
 							&heap, node->heap, NULL,
