@@ -1,4 +1,4 @@
-/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2015, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
@@ -45,7 +45,7 @@ static const TABLE_FIELD_TYPE field_types[]=
   {
     { C_STRING_WITH_LEN("VARIABLE_VALUE") },
 #ifdef WITH_WSREP
-    { C_STRING_WITH_LEN("varchar(2048)") },
+    { C_STRING_WITH_LEN("varchar(" WSREP_PS_VAR_VALUE_BUFF_SIZE_STR ")") },
 #else
     { C_STRING_WITH_LEN("varchar(1024)") },
 #endif /* WITH_WSREP */
@@ -57,6 +57,11 @@ TABLE_FIELD_DEF
 table_global_variables::m_field_def=
 { 2, field_types };
 
+PFS_engine_table_share_state
+table_global_variables::m_share_state = {
+  false /* m_checked */
+};
+
 PFS_engine_table_share
 table_global_variables::m_share=
 {
@@ -69,8 +74,9 @@ table_global_variables::m_share=
   sizeof(pos_t),
   &m_table_lock,
   &m_field_def,
-  false, /* checked */
-  true   /* perpetual */
+  true, /* m_perpetual */
+  false, /* m_optional */
+  &m_share_state
 };
 
 PFS_engine_table*
